@@ -603,12 +603,17 @@ class HumanClient(Client):
     def startLocalServer(useSocket):
         """start a local server"""
         try:
-            args = ' '.join([
-                '--showtraffic'  if InternalParameters.showTraffic else '',
-                '--socket=%s' % socketName() if useSocket else '']).lstrip()
-            process = subprocess.Popen(['kajonggserver', args])
+            cmd = './kajonggserver.py'
+            if not os.path.exists(cmd):
+                cmd = 'kajonggserver'
+            args = [cmd]
+            if InternalParameters.showTraffic:
+                args.append('--showtraffic')
+            if useSocket:
+                args.append('--socket=%s' % socketName())
+            process = subprocess.Popen(args)
             syslogMessage(m18n('started the local kajongg server: pid=<numid>%1</numid> %2',
-                process.pid, args))
+                process.pid, ' '.join(args)))
             if useSocket:
                 HumanClient.socketServerProcess = process
             else:
@@ -761,6 +766,9 @@ class HumanClient(Client):
         hostIdx = adduserDialog.cbServer.findText(host)
         if hostIdx >= 0:
             adduserDialog.cbServer.setCurrentIndex(hostIdx)
+        else:
+            adduserDialog.cbServer.insertItem(0, host)
+            adduserDialog.cbServer.setCurrentIndex(0)
         adduserDialog.username = self.loginDialog.username
         adduserDialog.password = self.loginDialog.password
         if not adduserDialog.exec_():
