@@ -435,7 +435,7 @@ void MainWindow::setGameCaption()
     if ( m_dealer )
     {
         const DealerInfo * di = m_dealer_map.value( m_dealer->gameId() );
-        caption = QString("%1 - %2").arg(di->name()).arg(m_dealer->gameNumber());
+        caption = QString("%1 - %2").arg( i18n( di->name() ) ).arg(m_dealer->gameNumber());
     }
     setCaption( caption );
 }
