@@ -3,7 +3,7 @@
  *   Copyright 1997  Mario Weilguni <mweilguni@sime.com>                   *
  *   Copyright 2002-2004  Dave Corrie <kde@davecorrie.com>                 *
  *   Copyright 2007  Mauricio Piacentini <mauricio@tabuleiro.com>          *
- *   Copyright 2009  Frederik Schwarzer <schwarzerf@gmail.com>             *
+ *   Copyright 2009,2010  Frederik Schwarzer <schwarzerf@gmail.com>        *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,7 +24,7 @@
 #include "ui_settings.h"
 
 #include <kmahjonggconfigdialog.h>
-#include <kscoredialog.h>
+#include <highscore/kscoredialog.h>
 #include <kstandardgameaction.h>
 
 #include <kaction.h>
@@ -107,7 +107,7 @@ void App::setupStatusBar()
 void App::setupActions()
 {
     // Game
-    KStandardGameAction::gameNew(this, SLOT(newGame()), actionCollection());
+    KStandardGameAction::gameNew(this, SIGNAL(invokeNewGame()), actionCollection());
     KStandardGameAction::restart(this, SLOT(restartGame()), actionCollection());
     KStandardGameAction::pause(this, SLOT(togglePause()), actionCollection());
     KStandardGameAction::highscores(this, SLOT(showHighscores()), actionCollection());
@@ -140,11 +140,13 @@ void App::setupActions()
 
     connect(m_board, SIGNAL(changed()), this, SLOT(updateTileDisplay()));
     connect(m_board, SIGNAL(endOfGame()), this, SLOT(slotEndOfGame()));
+
+    connect(this, SIGNAL(invokeNewGame()), m_board, SLOT(newGame()));
+    connect(m_board, SIGNAL(newGameStarted()), this, SLOT(newGame()));
 }
 
 void App::newGame()
 {
-    m_board->newGame();
     setCheatModeEnabled(false);
     setPauseEnabled(false);
     updateItems();
@@ -156,13 +158,12 @@ void App::restartGame()
     while (m_board->canUndo()) {
         m_board->undo();
     }
-    m_board->setUpdatesEnabled(true);
     m_board->resetRedo();
     m_board->resetTimer();
     setCheatModeEnabled(false);
     m_board->setGameOverEnabled(false);
     m_board->setGameStuckEnabled(false);
-    m_board->update();
+    m_board->setUpdatesEnabled(true);
     updateItems();
 }
 
