@@ -1,6 +1,6 @@
 /*
     This file is part of the KDE games library
-    Copyright (C) 2001 Martin Heni (martin@heni-online.de)
+    Copyright (C) 2001 Martin Heni (kde at heni-online.de)
     Copyright (C) 2001 Andreas Beckermann (b_mann@gmx.de)
 
     This library is free software; you can redistribute it and/or
@@ -14,19 +14,17 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #ifndef __KPLAYER_H_
 #define __KPLAYER_H_
 
-#include <qstring.h>
-#include <qobject.h>
-#include <qptrlist.h>
+#include <QtCore/QObject>
+#include <QtCore/QList>
 
-#include "kgameproperty.h"
-#include <kdemacros.h>
+#include <libkdegames_export.h>
 
 class KGame;
 class KGameIO;
@@ -36,6 +34,8 @@ class KGamePropertyHandler;
 class KPlayerPrivate;
 
 /**
+ * \class KPlayer kplayer.h <KPlayer>
+ * 
  * @short Base class for a game player
  *
  * The KPlayer class is the central player object. It holds
@@ -66,26 +66,19 @@ class KPlayerPrivate;
  * functions which are shared by all of your KGameIOs.
  *
  */
-class KDE_EXPORT KPlayer : public QObject
+class KDEGAMES_EXPORT KPlayer : public QObject
 {
   Q_OBJECT
 
 public:
-      typedef QPtrList<KGameIO> KGameIOList;
+      typedef QList<KGameIO*> KGameIOList;
 
       // KPlayer(KGame *,KGameIO * input=0);
       /**
        * Create a new player object. It will be automatically
        * deleted if the game it belongs to is deleted.
        */
-      KPlayer();
-
-      /**
-       * Create a new player object. It will be automatically
-       * deleted if the game it belongs to is deleted. This constructor
-       * automatically adds the player to the game using KGame::addPlayer()
-       */
-      KPlayer(KGame* game);
+      explicit KPlayer();
 
       virtual ~KPlayer();
 
@@ -95,7 +88,7 @@ public:
       *
       * @return 0 for default KPlayer.
       */
-      virtual int rtti() const {return 0;}
+      virtual int rtti() const;
 
       /**
       * Gives debug output of the game status
@@ -108,7 +101,7 @@ public:
        *
        * @return list of devices
        */
-      KGameIOList *ioList() {return &mInputList;}
+      KGameIOList *ioList();
 
       /**
        * sets the game the player belongs to. This
@@ -117,14 +110,14 @@ public:
        *
        * @param game the game
        */
-      void setGame(KGame *game) {mGame=game;}
+      void setGame(KGame *game);
 
       /**
        * Query to which game the player belongs to
        *
        * @return the game
        */
-      KGame *game() const {return mGame;}
+      KGame *game() const;
 
       /**
        * Set whether this player can make turns/input
@@ -133,7 +126,7 @@ public:
        *
        * @param a async=true turn based=false
        */
-      void setAsyncInput(bool a) {mAsyncInput = a;}
+      void setAsyncInput(bool a);
 
       /**
        * Query whether this player does asynchronous 
@@ -141,7 +134,7 @@ public:
        *
        * @return true/false
        */
-      bool asyncInput() const {return mAsyncInput.value();}
+      bool asyncInput() const;
 
       /**
        * Is this player a virtual player, ie is it 
@@ -170,28 +163,28 @@ public:
        *
        * @return true/false
        */
-      bool isActive() const {return mActive;}
+      bool isActive() const;
 
       /**
        * Set an player as active (true) or inactive (false)
        *
        * @param v true=active, false=inactive
        */
-      void setActive(bool v) {mActive=v;}
+      void setActive(bool v);
 
       /**
        * Returns the id of the player
        *
        * @return the player id
        */
-      Q_UINT32 id() const; 
+      quint32 id() const; 
 
       /* Set the players id. This is done automatically by
        * the game object when adding a new player!
        *
        * @param i the player id
        */
-      void setId(Q_UINT32 i);
+      void setId(quint32 i);
 
       /**
        * Returns the user defined id of the player
@@ -204,13 +197,13 @@ public:
        *
        * @return the user defined player id
        */
-      int userId() const {return mUserId.value();} 
+      int userId() const;
 
       /* Set the user defined players id.
        *
        * @param i the user defined player id
        */
-      void setUserId(int i) {mUserId = i;}
+      void setUserId(int i);
 
       /**
        * Returns whether this player can be replaced by a network
@@ -318,7 +311,7 @@ public:
        * @param rtti the rtti typed to be checked for
        * @return true if it exists
        */
-      bool hasRtti(int rtti) const  {return findRttiIO(rtti)!=0;}
+      bool hasRtti(int rtti) const;
 
       // Message exchange
       /**
@@ -333,12 +326,12 @@ public:
        * KGame::playerInput() (if player=false, ie the message *was* sent through
        * KGame::sendPlayerInput).
        */
-      virtual bool forwardInput(QDataStream &msg,bool transmit=true, Q_UINT32 sender=0);
+      virtual bool forwardInput(QDataStream &msg,bool transmit=true, quint32 sender=0);
 
       /**
        * Forwards Message to the game object..internal use only
        */
-      virtual bool forwardMessage(QDataStream &msg,int msgid,Q_UINT32 receiver=0,Q_UINT32 sender=0);
+      virtual bool forwardMessage(QDataStream &msg,int msgid,quint32 receiver=0,quint32 sender=0);
 
       // Game logic
       /**
@@ -346,7 +339,7 @@ public:
        *
        * @return true/false
        */
-      bool myTurn() const {return mMyTurn.value();}
+      bool myTurn() const;
 
       /**
        * Sets whether this player is the next to turn.
@@ -390,7 +383,7 @@ public:
        * @param stream The message itself
        * @param sender 
        **/
-      void networkTransmission(QDataStream &stream,int msgid,Q_UINT32 sender);
+      void networkTransmission(QDataStream &stream,int msgid,quint32 sender);
 
       /**
        * Searches for a property of the player given its id. 
@@ -423,14 +416,14 @@ public:
         */
        KGamePropertyHandler* dataHandler();
 
-signals:
+Q_SIGNALS:
       /**
        *  The player object got a message which was targeted
        *  at it but has no default method to process it. This
        *  means probably a user message. Connecting to this signal
        *  allowed to process it.
        */
-       void signalNetworkData(int msgid, const QByteArray& buffer, Q_UINT32 sender, KPlayer *me);
+       void signalNetworkData(int msgid, const QByteArray& buffer, quint32 sender, KPlayer *me);
 
        /**
         * This signal is emmited if a player property changes its value and
@@ -440,7 +433,7 @@ signals:
         */
        void signalPropertyChanged(KGamePropertyBase *property,KPlayer *me);
 
-protected slots:
+protected Q_SLOTS:
       /**
        * Called by KGameProperty only! Internal function!
        **/
@@ -455,17 +448,10 @@ private:
       void init();
 
 private:
-      KGame *mGame;
-      bool mActive;      // active player
-      KGameIOList mInputList;
+      friend class KPlayerPrivate;
+      KPlayerPrivate *const d;
 
-      // GameProperty // AB: I think we can't move them to KPlayerPrivate - inline
-      // makes sense here
-      KGamePropertyBool mAsyncInput;  // async input allowed
-      KGamePropertyBool mMyTurn;      // Is it my turn to play (only useful if not async)?
-      KGamePropertyInt  mUserId;      // a user defined id
-
-      KPlayerPrivate* d;
+      Q_DISABLE_COPY(KPlayer)
 };
 
 #endif
