@@ -65,7 +65,7 @@
 #include <config-src.h>
 
 // Forward declarations
-const int ADVANCE_PERDIOD =  20;
+const int ADVANCE_PERIOD =  20;
 
 // Shortcut to access the actions
 #define ACTION(x)   (actionCollection()->action(x))
@@ -158,12 +158,14 @@ Mainwindow::Mainwindow(QWidget* parent)
 
   // Overall view
   mCanvas        = new QGraphicsScene(this);
-  mView          = new GameView(QSize(880, 675), ADVANCE_PERDIOD, mCanvas, mTheme, this);
+  mView          = new GameView(QSize(880, 675), ADVANCE_PERIOD, mCanvas, mTheme, this);
 
   // Create intro
   mGameMode      = Intro;
-  mDisplay       = new DisplayIntro(mDeck, mCanvas, mTheme, ADVANCE_PERDIOD, mView);
+  mDisplay       = new DisplayIntro(mDeck, mCanvas, mTheme, ADVANCE_PERIOD, mView);
   setCentralWidget(mView);
+  connect(mView, SIGNAL(signalLeftMousePress(QPoint)),
+            this, SLOT(menuNewLSkatGame()));
 
   // Create GUI
   setupGUI();
@@ -583,6 +585,9 @@ void Mainwindow::menuEndGame()
 // Start a new game
 void Mainwindow::menuNewLSkatGame()
 {
+  disconnect(mView, SIGNAL(signalLeftMousePress(QPoint)),
+            this, SLOT(menuNewLSkatGame()));
+
   Player* p1 = mLSkatConfig->player(0);
   Player* p2 = mLSkatConfig->player(1);
 
@@ -602,7 +607,7 @@ void Mainwindow::menuNewLSkatGame()
     if (mDisplay) delete mDisplay;
     if (mEngine) delete mEngine;
 
-    mDisplay = new DisplayTwo(mDeck, mCanvas, mTheme, ADVANCE_PERDIOD, mView);
+    mDisplay = new DisplayTwo(mDeck, mCanvas, mTheme, ADVANCE_PERIOD, mView);
     mEngine = new EngineTwo(this, mDeck, (DisplayTwo*)mDisplay);
     connect(mEngine, SIGNAL(signalGameOver(int)), this, SLOT(gameOver(int)));
     connect(mEngine, SIGNAL(signalNextPlayer(Player*)), this, SLOT(nextPlayer(Player*)));
